// RW Windowing System
// ===================
// -The software testbed for adapting RW systems to use the FLTK GUI backend

// filename: Window.hpp
// -The declarations interface of the Window class

#pragma once

#include <string>

#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Sys_Menu_Bar.H>

namespace rw {

/** A basic system window; a wrapper class derived from @c Fl_Double_Window
 */
class Window : public Fl_Double_Window {
 public:
  /** Parameterized @c Window constructor, W & H edition
   * @param[in] width
   * @param[in] height
   * @param[in] label optional @c string gets passed on as a @c C-string to the
   * FLTK base class
   * @note: A window callback and menubar are assigned during construction.
   *
   * TODO: turn this into a delegated-ctor wrapper for the 'posn, w&h edition'.
   */
  Window(int const width, int const height, std::string const& label = "");

  /** Display the window
   * @param[in] argc the CLI arguments count
   * @param[in] argv the CLI arguments C-string array
   * @return the FLTK system's exit code
   * @note: the window's @c show() member, then the FLTK static @c run()
   * function, are called, in order.
   */
  int display(int argc, char** argv);

 private:
  int         width_{700};
  int         height_{30};  // needs to be at least 30 for default font display
  Fl_Menu_Bar menubar_{0, 0, width_, height_};
};

}  // namespace rw

// Copyright (2021)
// License MIT (Expat) https://opensource.org/licenses/MIT
