// RW Windowing System
// ===================
// -The software testbed for adapting RW systems to use the FLTK GUI backend

// filename: callbacks.hpp
// -The definitions of the system's callback functions

#pragma once

#include <cstdio>
#include <cstdlib>

#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>

using std::puts;

namespace rw {

//------------------------------------------------------------------------------
/** Activates when window exits
 * @param[in] w general @c Widget ptr
 * @param[in] na user data ptr
 */
static void window_cb(Fl_Widget* w, void*) {
  puts("   |> window_cb callback called");  // TEST:
  ((Fl_Double_Window*)w)->hide();
}

//------------------------------------------------------------------------------
/** Activates when 'File > Quit' menu item is chosen
 * @param[in] na general @c Widget ptr
 * @param[in] na user data ptr
 */
static void quit_cb(Fl_Widget*, void*) {
  puts("   |> quit_cb callback called");  // TEST:
  std::exit(0);
}

}  // namespace rw

// Copyright (2021)
// License MIT (Expat) https://opensource.org/licenses/MIT
